{% load static django_tableaux %}
<div id="block_content">
  {% if view.filterset_class and view.filter_style == 1 %}
    <div class="{{ css_toolbar }}">
      {% include "django_tableaux/filter_toolbar.html" %}
    </div>
  {% endif %}
  {% if view.filter_pills and filters %}
    <div class="{{ css_toolbar }} d-flex">
      {% include "django_tableaux/toolbar/_filter_pills.html" %}
    </div>
  {% endif %}
  {% if actions or buttons or table.column_states or view.filterset_class and view.filter_modal %}
    <div class="{{ css_toolbar }}">
      {% include "django_tableaux/toolbar/main.html" %}
    </div>
  {% endif %}
    {% include "django_tableaux/bootstrap4/render_table.html" %}
  <div id="modals-here"></div>
</div>